@@ -1,5 +1,4 @@
 # -*- coding: utf8 -*-
-import sys
 import os.path
 import numpy as np
 import PDielec.Calculator as Calculator
@@ -8,14 +7,12 @@ from PyQt5.QtWidgets  import  QComboBox, QLabel, QLineEdit, QDoubleSpinBox
 from PyQt5.QtWidgets    import  QVBoxLayout, QHBoxLayout, QFormLayout
 from PyQt5.QtWidgets    import  QSpinBox
 from PyQt5.QtWidgets    import  QFileDialog
-from PyQt5.QtWidgets    import  QTableWidget
 from PyQt5.QtWidgets    import  QTableWidgetItem
 from PyQt5.QtWidgets    import  QSizePolicy
 from PyQt5.QtWidgets    import  QCheckBox
 from PyQt5.QtWidgets    import  QTabWidget
 from PyQt5.QtCore       import  Qt
 from PyQt5.QtCore       import  QCoreApplication
-from PyQt5.QtCore       import  QSize
 from PDielec.Utilities   import  Debug
 from PDielec.GUI.SettingsTab import  FixedQTableWidget
 # Import plotting requirements
@@ -23,8 +20,6 @@ import matplotlib
 import matplotlib.figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as NavigationToolbar
-from PDielec.Utilities import Debug
-import time
 from openpyxl import load_workbook
 from scipy.interpolate import interp1d
 from scipy.optimize import minimize
@@ -46,8 +41,8 @@ class FitterTab(QWidget):
         self.settings['Fitting type'] = 'Minimise x-correlation'
         self.fitting_type_definitions = ['Minimise x-correlation', 'Minimise spectral difference']
         self.settings['Number of iterations'] = 20
-        self.settings['Frequency scaling'] = False
         self.settings['Frequency scaling factor'] = 1.0
+        self.settings['Optimise frequency scaling'] = False
         self.settings['Absorption scaling'] = False
         self.settings['Absorption scaling factor'] = 1.0
         self.settings['Independent y-axes'] = True
@@ -96,16 +91,8 @@ class FitterTab(QWidget):
         #
         # See if we want frequency scaling
         #
-        self.frequency_scaling_cb = QCheckBox(self)
-        self.frequency_scaling_cb.setToolTip('Frequency scaling is applied during the fitting process')
-        self.frequency_scaling_cb.setText('')
-        self.frequency_scaling_cb.setLayoutDirection(Qt.RightToLeft)
-        if self.settings['Frequency scaling']:
-            self.frequency_scaling_cb.setCheckState(Qt.Checked)
-        else:
-            self.frequency_scaling_cb.setCheckState(Qt.Unchecked)
-        self.frequency_scaling_cb.stateChanged.connect(self.on_frequency_scaling_cb_changed)
         self.frequency_scaling_factor_sb = QDoubleSpinBox(self)
+        self.frequency_scaling_factor_sb.setToolTip('Frequency scaling factor')
         self.frequency_scaling_factor_sb.setRange(0.000001,10000000.0)
         self.frequency_scaling_factor_sb.setDecimals(4)
         self.frequency_scaling_factor_sb.setSingleStep(0.1)
@@ -116,10 +103,10 @@ class FitterTab(QWidget):
         # See if we want base line removal
         #
         self.baseline_cb = QCheckBox(self)
-        self.baseline_cb.setToolTip('Frequency scaling is applied during the fitting process')
+        self.baseline_cb.setToolTip('Apply base line correction')
         self.baseline_cb.setText('')
         self.baseline_cb.setLayoutDirection(Qt.RightToLeft)
-        if self.settings['Frequency scaling']:
+        if self.settings['Baseline removal']:
             self.baseline_cb.setCheckState(Qt.Checked)
         else:
             self.baseline_cb.setCheckState(Qt.Unchecked)
@@ -157,17 +144,27 @@ class FitterTab(QWidget):
         else:
             self.independent_yaxes_cb.setCheckState(Qt.Unchecked)
         self.independent_yaxes_cb.stateChanged.connect(self.on_independent_yaxes_cb_changed)
+        # Optimise frequency scaling?
+        self.optimise_frequency_scaling_cb = QCheckBox(self)
+        self.optimise_frequency_scaling_cb.setToolTip('Use frequency scaling in optimisation')
+        self.optimise_frequency_scaling_cb.setText('')
+        self.optimise_frequency_scaling_cb.setLayoutDirection(Qt.RightToLeft)
+        if self.settings['Optimise frequency scaling']:
+            self.optimise_frequency_scaling_cb.setCheckState(Qt.Checked)
+        else:
+            self.optimise_frequency_scaling_cb.setCheckState(Qt.Unchecked)
+        self.optimise_frequency_scaling_cb.stateChanged.connect(self.on_optimise_frequency_scaling_cb_changed)
         #
         # Add a tab widget for the settings ######################################################################################
         #
         self.settingsTab = QTabWidget(self)
         self.settingsTab.addTab(self.spectrafile_le, 'Experimental spectrum')
         self.settingsTab.addTab(self.plot_type_cb, 'Plot type')
-        self.settingsTab.addTab(self.frequency_scaling_cb, 'Frequency scaling?')
         self.settingsTab.addTab(self.frequency_scaling_factor_sb, 'Frequency scaling factor')
         self.settingsTab.addTab(self.iterations_sb, 'No. of iterations')
         self.settingsTab.addTab(self.independent_yaxes_cb, 'Independent y-axes')
         self.settingsTab.addTab(self.fitting_type_cb, 'Fitting type')
+        self.settingsTab.addTab(self.optimise_frequency_scaling_cb, 'Optimise scaling')
         self.settingsTab.addTab(self.spectral_difference_threshold_sb, 'Spectral difference threshold')
         self.settingsTab.addTab(self.baseline_cb, 'Baseline removal?')
         self.settingsTab.addTab(self.hpfilter_lambda_sb, 'HP Filter Lambda')
@@ -257,6 +254,11 @@ class FitterTab(QWidget):
         self.settings['Independent y-axes'] = self.independent_yaxes_cb.isChecked()
         return
 
+    def on_optimise_frequency_scaling_cb_changed(self,value):
+        debugger.print('optimise_frequency_scaling_cb_changed',value)
+        self.settings['Optimise frequency scaling'] = self.optimise_frequency_scaling_cb.isChecked()
+        return
+
     def on_absorption_scaling_cb_changed(self,value):
         debugger.print('on_absorption_scaling_cb_changed',value)
         self.settings['Absorption scaling'] = self.absorption_scaling_cb.isChecked()
@@ -284,12 +286,7 @@ class FitterTab(QWidget):
         self.settings['Baseline removal'] = self.baseline_cb.isChecked()
         self.replot()
         return
- 
-    def on_frequency_scaling_cb_changed(self,value):
-        debugger.print('on_frequency_scaling_cb_changed',value)
-        self.settings['Frequency scaling'] = self.frequency_scaling_cb.isChecked()
-        return
- 
+
     def on_spectral_difference_threshold_sb_changed(self,value):
         debugger.print('on_spectral_difference_threshold_sb_changed',value)
         try:
@@ -348,7 +345,8 @@ class FitterTab(QWidget):
             scale_calc = scale * self.settings['Frequency scaling factor']
         else:
             lag = 0.0
-            scale_calc = scale
+            # scale_calc = scale
+            scale_calc = scale * self.settings['Frequency scaling factor']
         for x,y,legend in zip(xs,ys,legends):
             x = np.array(x)
             line, = self.subplot1.plot(lag+scale_calc*x,y,lw=2, color=cmap(cmap_index), label=legend )
@@ -380,7 +378,6 @@ class FitterTab(QWidget):
             self.fittingButton.setText('Interupt fitting')
             self.calculationInProgress = True
         self.refresh()
-        final_point = self.optimiseFit()
         self.fittingButton.setText('Perform fitting')
         self.calculationInProgress = False
         return
@@ -396,7 +393,7 @@ class FitterTab(QWidget):
                 self.fit_list.append(mode)
         initial_point = [ self.sigmas_cm1[i] for i in self.fit_list ]
         # Append a scaling option
-        if self.settings['Frequency scaling']:
+        if self.settings['Optimise frequency scaling']:
             initial_point.append(self.settings['Frequency scaling factor'])
         nvariables = len(initial_point)
         if nvariables > 0:
@@ -416,7 +413,7 @@ class FitterTab(QWidget):
         self.functionCalls += 1
         nvariables = len(variables)
         self.fittingButton.setText('Interrupt fitting ({}/{})'.format(self.functionCalls,nvariables+1+nvariables*self.settings['Number of iterations']))
-        if self.settings['Frequency scaling']:
+        if self.settings['Optimise frequency scaling']:
             sigmas = variables[:-1]
             scaling_factor = variables[-1]
             self.settings['Frequency scaling factor'] = scaling_factor
@@ -617,7 +614,7 @@ class FitterTab(QWidget):
         if len(self.excel_absorption) > 0:
             self.resample_spectrum()
         self.plot(self.experimental_absorption,self.calculated_frequencies,self.calculated_absorptions,self.legends,self.plot_label)
-        
+
     def refresh(self,force=False):
         if not self.dirty and not force and not self.notebook.fittingCalculationRequired:
             debugger.print('refresh aborted', self.dirty,force)
@@ -635,10 +632,6 @@ class FitterTab(QWidget):
         self.read_excel_file()
         self.plot_type_cb.setCurrentIndex(self.plot_type_definitions.index(self.settings['Plot type']))
         self.iterations_sb.setValue(self.settings['Number of iterations'])
-        if self.settings['Frequency scaling']:
-            self.frequency_scaling_cb.setCheckState(Qt.Checked)
-        else:
-            self.frequency_scaling_cb.setCheckState(Qt.Unchecked)
         self.frequency_scaling_factor_sb.setValue(self.settings['Frequency scaling factor'])
         if self.settings['Independent y-axes']:
             self.independent_yaxes_cb.setCheckState(Qt.Checked)
