@@ -1,4 +1,3 @@
-import sys
 import os.path
 from PyQt5.QtWidgets  import  QWidget
 from PyQt5.QtWidgets  import  QListWidget, QComboBox, QLabel, QLineEdit
@@ -6,7 +5,7 @@ from PyQt5.QtWidgets  import  QFileDialog, QPushButton, QCheckBox
 from PyQt5.QtWidgets  import  QFormLayout, QApplication
 from PyQt5.QtWidgets  import  QVBoxLayout, QMessageBox
 from PyQt5.QtCore     import  Qt, QCoreApplication
-from PDielec.Utilities import  get_reader, Debug
+from PDielec.Utilities import  pdgui_get_reader, Debug
 from PDielec.GUI.SpreadSheetManager import SpreadSheetManager
 import numpy as np
 
@@ -187,7 +186,7 @@ class MainTab(QWidget):
         debugger.print('Read output file - clear list widget')
         self.listw.clear()
         self.listw_l.setText('Frequencies from '+self.settings['Output file name'])
-        self.reader = get_reader(self.settings['Program'],[ self.settings['Output file name'] ], self.settings['QM program'] )
+        self.reader = pdgui_get_reader(self.settings['Program'],[ self.settings['Output file name'] ], self.settings['QM program'] )
         if self.reader is None:
             print('Error in reading files - program  is ',self.settings['Program'])
             print('Error in reading files - filename is ',self.settings['Output file name'])
@@ -236,6 +235,8 @@ class MainTab(QWidget):
         debugger.print('processing a return')
         if hasattr(self.notebook, 'settingsTab'):
             debugger.print('about to refresh settings')
+            # There is a subtle problem with the sigmas, they need to be reset on reading a new file
+            self.notebook.settingsTab.sigmas_cm1 = []
             self.notebook.settingsTab.refresh(True)
         # Update any scenarios
         if hasattr(self.notebook, 'scenarios'):
@@ -265,6 +266,8 @@ class MainTab(QWidget):
             debugger.print('notebook has no viewer tab yet')
         # Update the fitter tab
         if hasattr(self.notebook, 'fitterTab'):
+            # There is a subtle problem with the modes that are to be fitted, they need resetting
+            self.notebook.fitterTab.modes_fitted = []
             debugger.print('about to refresh fitterTab')
             self.notebook.fitterTab.refresh()
         else:
