@@ -1,9 +1,8 @@
-import sys
 import os.path
 import os
 import numpy as np
 osname = os.name
-from multiprocessing import cpu_count, Array
+from multiprocess import Array
 import PDielec.Calculator as Calculator
 from PyQt5.QtWidgets  import  QPushButton, QWidget
 from PyQt5.QtWidgets  import  QComboBox, QLabel, QLineEdit
@@ -12,8 +11,7 @@ from PyQt5.QtWidgets  import  QVBoxLayout, QHBoxLayout, QFormLayout
 from PyQt5.QtWidgets  import  QSpinBox,QDoubleSpinBox
 from PyQt5.QtWidgets  import  QSizePolicy
 from PyQt5.QtCore     import  QCoreApplication, Qt
-from PDielec.Constants import  wavenumber, amu, PI, avogadro_si, angstrom
-from PDielec.Constants import  average_masses, isotope_masses
+from PDielec.Constants import  wavenumber, PI, avogadro_si, angstrom
 import ctypes
 # Import plotting requirements
 import matplotlib
@@ -21,7 +19,6 @@ import matplotlib.figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as NavigationToolbar
 from PDielec.Utilities import Debug
-import time
 
 def set_affinity_on_worker():
     '''When a new worker process is created, the affinity is set to all CPUs'''
@@ -55,11 +52,6 @@ class PlottingTab(QWidget):
         self.notebook = parent
         # get the reader from the main tab
         self.reader = self.notebook.mainTab.reader
-        # Create the parallel environment
-        if self.notebook.threading:
-            from multiprocessing.dummy import Pool
-        else:
-            from multiprocessing import Pool
         # Create last tab - PlottingTab
         vbox = QVBoxLayout()
         form = QFormLayout()
@@ -368,21 +360,17 @@ class PlottingTab(QWidget):
         # Assemble the settingsTab settings
         self.notebook.plottingCalculationRequired = False
         settings = self.notebook.settingsTab.settings
-        eckart = settings['Eckart flag']
-        neutral = settings['Neutral Born charges']
         epsilon_inf = np.array(settings['Optical permittivity'])
         sigmas_cm1 = self.notebook.settingsTab.sigmas_cm1
         sigmas = np.array(sigmas_cm1) * wavenumber
         modes_selected = self.notebook.settingsTab.modes_selected
         frequencies_cm1 = self.notebook.settingsTab.frequencies_cm1
         frequencies = np.array(frequencies_cm1) * wavenumber
-        intensities = self.notebook.settingsTab.intensities
         oscillator_strengths = self.notebook.settingsTab.oscillator_strengths
         volume = reader.volume*angstrom*angstrom*angstrom
         vmin = self.settings['Minimum frequency']
         vmax = self.settings['Maximum frequency']
         vinc = self.settings['Frequency increment']
-        calling_parameters = []
         self.scenarios = self.notebook.scenarios
         mode_list = []
         drude_sigma = 0
@@ -393,8 +381,6 @@ class PlottingTab(QWidget):
                 mode_list.append(mode_index)
         #debugger.print('mode_list', mode_list)
         # Calculate the ionic permittivity at zero frequency
-        epsilon_ionic = self.notebook.settingsTab.epsilon_ionic
-        epsilon_total = epsilon_inf + epsilon_ionic
         cell = reader.unit_cells[-1]
         self.directions = []
         self.depolarisations = []
@@ -437,17 +423,21 @@ class PlottingTab(QWidget):
         if self.notebook.progressbar is not None:
             self.notebook.progressbar.setMaximum(maximum_progress)
         QCoreApplication.processEvents()
-        # Lets find ouit how many processors to use
-        if self.notebook.ncpus == 0:
-            number_of_processors = cpu_count()
-        else:
-            number_of_processors = self.notebook.ncpus
+        number_of_processors = self.notebook.ncpus
+        #
+        # Switch off mkl threading
+        #
+        try:
+            import mkl
+            mkl.set_num_threads(1)
+        except:
+            pass
         #jk start = time.time()
         if self.notebook.threading:
-            from multiprocessing.dummy import Pool
+            from multiprocess.dummy import Pool
             pool = Pool(number_of_processors)
         else:
-            from multiprocessing import Pool
+            from multiprocess import Pool
             pool = Pool(number_of_processors, initializer=set_affinity_on_worker, maxtasksperchild=10)
         dielecv_results = []
         for result in pool.imap(Calculator.parallel_dielectric, call_parameters,chunksize=40):
@@ -480,18 +470,15 @@ class PlottingTab(QWidget):
         self.sp_atrs = []
         #jk start = time.time()
         if self.notebook.threading:
-            from multiprocessing.dummy import Pool
+            from multiprocess.dummy import Pool
             pool = Pool(number_of_processors)
         else:
-            from multiprocessing import Pool
+            from multiprocess import Pool
             pool = Pool(number_of_processors, initializer=set_affinity_on_worker, maxtasksperchild=10)
         for i,(scenario,L) in enumerate(zip(self.scenarios,self.depolarisations)):
             #debugger.print('Scenario ',i,L)
-            matrix = scenario.settings['Matrix']
             method = scenario.settings['Effective medium method'].lower()
-            matrix_density = scenario.settings['Matrix density']
             matrix_permittivity = np.identity(3) * scenario.settings['Matrix permittivity']
-            mass_fraction = scenario.settings['Mass fraction']
             volume_fraction = scenario.settings['Volume fraction']
             particle_size_mu = scenario.settings['Particle size(mu)']
             particle_sigma_mu = scenario.settings['Particle size distribution sigma(mu)']
@@ -545,6 +532,14 @@ class PlottingTab(QWidget):
             self.sp_atrs.append(sp_atr)
         pool.close()
         pool.join()
+        #
+        # Switch on mkl threading
+        #
+        try:
+            import mkl
+            mkl.set_num_threads(number_of_processors)
+        except:
+            pass
         #jk print('Dielec calculation duration ', time.time()-start)
         #if self.notebook.spreadsheet is not None:
         #    self.write_spreadsheet()
