@@ -1,19 +1,19 @@
 import os
-import math
 import numpy as np
-import PDielec.Calculator as Calculator
-from collections import deque
-from PyQt5.QtWidgets         import  QPushButton, QWidget
-from PyQt5.QtWidgets         import  QComboBox, QLabel, QLineEdit
-from PyQt5.QtWidgets         import  QVBoxLayout, QHBoxLayout, QFormLayout
-from PyQt5.QtWidgets         import  QSpinBox, QTabWidget, QDoubleSpinBox
-from PyQt5.QtWidgets         import  QSizePolicy, QColorDialog, QMessageBox, QApplication
-from PyQt5.QtCore            import  Qt
-from PDielec.Constants        import  wavenumber, amu, PI, avogadro_si, angstrom
+from collections              import  deque
+from PyQt5.QtWidgets          import  QPushButton, QWidget
+from PyQt5.QtWidgets          import  QComboBox, QLabel, QLineEdit
+from PyQt5.QtWidgets          import  QVBoxLayout, QHBoxLayout, QFormLayout
+from PyQt5.QtWidgets          import  QSpinBox, QTabWidget, QDoubleSpinBox
+from PyQt5.QtWidgets          import  QSizePolicy, QColorDialog, QMessageBox, QApplication
+from PyQt5.QtCore             import  Qt
+from PDielec.Constants        import  wavenumber, angstrom
 from PDielec.Constants        import  elemental_colours
 # Import plotting requirements
 from PDielec.Utilities        import Debug
 from PDielec.GUI.OpenGLWidget import OpenGLWidget
+# Need the SuperCell class
+from PDielec.SuperCell        import SuperCell
 
 class ViewerTab(QWidget):
     def __init__(self, parent, debug=False ):
@@ -36,6 +36,7 @@ class ViewerTab(QWidget):
         self.settings['Arrow colour']          = [   0, 255,   0, 255 ]
         self.settings['Arrow radius']          = 0.07
         self.settings['Number of phase steps'] = 41
+        self.settings['Super Cell'] =  [ 1, 1, 1 ]
         self.light_switches = [False]*8
         self.light_switches[0] = True
         self.light_switches[1] = True
@@ -43,6 +44,7 @@ class ViewerTab(QWidget):
         self.plot_type_index = 1
         self.number_of_molecules = 0
         self.unit_cell = None
+        self.super_cell = None
         self.cell_edges = None
         self.cell_corners = None
         # element_colours is a dictionary
@@ -82,6 +84,24 @@ class ViewerTab(QWidget):
         label = QLabel('Frequency (cm-1)', self)
         form.addRow(label, self.frequency_le)
         #
+        # The super-cell
+        #
+        self.super_cell_widget = QWidget(self)
+        self.super_cell_widget.setToolTip('Generate a super-cell')
+        self.super_cell_hbox = QHBoxLayout()
+        self.super_cell_spinBoxes = []
+        super_cell_changed = [self.on_super_cell_changed_a, self.on_super_cell_changed_b, self.on_super_cell_changed_c]
+        super_cell_tooltip = ['Size in a', 'Size in b', 'Size in c']
+        for i,change_function,tip in zip(self.settings['Super Cell'],super_cell_changed,super_cell_tooltip):
+            spinBox = QSpinBox(self)
+            spinBox.setToolTip(tip)
+            spinBox.setRange(1,5)
+            spinBox.setSingleStep(1)
+            spinBox.valueChanged.connect(change_function)
+            self.super_cell_spinBoxes.append(spinBox)
+            self.super_cell_hbox.addWidget(spinBox)
+        self.super_cell_widget.setLayout(self.super_cell_hbox)
+        #
         # The atom scaling
         #
         self.atom_scaling_sb = QDoubleSpinBox(self)
@@ -192,6 +212,7 @@ class ViewerTab(QWidget):
         self.settingsTab.addTab(self.coloured_elements_widget, 'Elements')
         self.settingsTab.addTab(self.coloured_buttons_widget, 'Colours')
         self.settingsTab.addTab(self.atom_scaling_sb, 'Atom Scaling')
+        self.settingsTab.addTab(self.super_cell_widget, 'Super Cell')
         self.settingsTab.addTab(self.light_switches_cb, 'Lighting')
         self.settingsTab.addTab(self.maximum_displacement_sb, 'Maximum Displacement')
         self.settingsTab.addTab(self.bond_radius_sb, 'Bond Radius')
@@ -217,12 +238,16 @@ class ViewerTab(QWidget):
         self.gif_filename_button = QPushButton('Save as gif')
         self.gif_filename_button.clicked.connect(self.on_filename_button_clicked)
         self.gif_filename_button.setToolTip('Save the animation as a gif file')
+        self.cif_filename_button = QPushButton('Save as cif')
+        self.cif_filename_button.clicked.connect(self.on_filename_button_clicked)
+        self.cif_filename_button.setToolTip('Save the animation as a cif file')
         label = QLabel('Image file name', self)
         label.setToolTip('Give a file name in which to save the image.\nIf a return is pressed the filename is scanned to see whatyoe of file has been requested.')
         hbox.addWidget(self.filename_le)
         hbox.addWidget(self.png_filename_button)
         hbox.addWidget(self.mp4_filename_button)
         hbox.addWidget(self.gif_filename_button)
+        hbox.addWidget(self.cif_filename_button)
         form.addRow(label, hbox)
         #
         # Add the opengl figure to the bottom
@@ -252,7 +277,7 @@ class ViewerTab(QWidget):
         #
         filename = self.image_filename
         root,extension = os.path.splitext(filename)
-        valid_extension = ( extension == '.mp4' or extension == '.avi' or extension == '.png' or extension == '.gif' )
+        valid_extension = ( extension == '.mp4' or extension == '.avi' or extension == '.png' or extension == '.gif' or extension == '.cif' )
         if filename == '' or not valid_extension:
             debugger.print('Aborting on filename button clicked', filename)
             debugger.print('Aborting on filename button clicked', valid_extension)
@@ -276,15 +301,41 @@ class ViewerTab(QWidget):
             self.opengl_widget.save_movie(filename)
         elif extension == '.gif':
             self.opengl_widget.save_movie(filename)
+        elif extension == '.cif':
+            self.save_cif(filename)
         self.plot_type_index = old_plot_type
         QApplication.restoreOverrideCursor()
         return
 
+    def on_super_cell_changed_a(self,newa):
+        a,b,c = self.settings['Super Cell']
+        a = newa
+        self.settings['Super Cell'] =  [ a, b, c ]
+        self.dirty = True
+        self.refresh()
+
+    def on_super_cell_changed_b(self,newb):
+        a,b,c = self.settings['Super Cell']
+        b = newb
+        self.settings['Super Cell'] =  [ a, b, c ]
+        self.dirty = True
+        self.refresh()
+
+    def on_super_cell_changed_c(self,newc):
+        a,b,c = self.settings['Super Cell']
+        c = newc
+        self.settings['Super Cell'] =  [ a, b, c ]
+        self.dirty = True
+        self.refresh()
+
     def on_coloured_element_clicked(self,boolean):
         debugger.print('on coloured elements clicked')
         button = self.sender()
         text = button.text()
-        colour = QColorDialog.getColor(options=QColorDialog.DontUseNativeDialog)
+        colourChooser = QColorDialog()
+        if colourChooser.exec_() != QColorDialog.Accepted:
+            return
+        colour = colourChooser.currentColor()
         rgba = [ colour.red(), colour.green(), colour.blue(), colour.alpha() ]
         self.element_colours[text] = rgba
         self.dirty = True
@@ -294,7 +345,10 @@ class ViewerTab(QWidget):
         debugger.print('on coloured button clicked')
         button = self.sender()
         text = button.text()
-        colour = QColorDialog.getColor(options=QColorDialog.DontUseNativeDialog)
+        colourChooser = QColorDialog()
+        if colourChooser.exec_() != QColorDialog.Accepted:
+            return
+        colour = colourChooser.currentColor()
         rgba = [ colour.red(), colour.green(), colour.blue(), colour.alpha() ]
         if text == 'Background':
             self.settings['Background colour'] = rgba
@@ -388,25 +442,25 @@ class ViewerTab(QWidget):
         settings = self.notebook.settingsTab.settings
         self.frequencies_cm1 = self.notebook.settingsTab.frequencies_cm1
         self.selected_mode_sb.setRange(0,len(self.frequencies_cm1)-1)
-        frequencies = np.array(self.frequencies_cm1) * wavenumber
-        intensities = self.notebook.settingsTab.intensities
-        oscillator_strengths = self.notebook.settingsTab.oscillator_strengths
-        volume = self.reader.volume*angstrom*angstrom*angstrom
         # Get the cell with whole molecules from the analysis tab
         self.unit_cell = self.notebook.analysisTab.cell_of_molecules
+        # Generate a super cell
+        imageSpecifier = self.settings["Super Cell"]
+        self.super_cell = SuperCell(self.unit_cell,imageSpecifier)
         # if self.debug:
         #     self.unit_cell.printInfo()
-        self.normal_modes = self.notebook.analysisTab.new_normal_modes
-        self.bonds = self.unit_cell.bonds
+        self.normal_modes = self.super_cell.calculateNormalModes(self.notebook.analysisTab.new_normal_modes)
+        self.bonds = self.super_cell.calculateBonds()
         self.snapshot_number = 0
         self.nbonds = len(self.bonds)
         #
-        self.XYZ = self.unit_cell.xyz_coordinates
+        self.XYZ = self.super_cell.calculateXYZ()
         self.natoms = len(self.XYZ)
         self.number_of_modes = len(self.normal_modes)
-        # get the cell edges for the bounding box
-        self.cell_corners,self.cell_edges = self.unit_cell.getBoundingBox()
-        self.element_names = self.unit_cell.element_names
+        # get the cell edges for the bounding box, shifted to the centre of mass origin
+        totalMass,centreOfMassXYZ,centreOfMassABC = self.super_cell.calculateCentreOfMass(units=all)
+        self.cell_corners,self.cell_edges = self.super_cell.getBoundingBox(centreOfMassABC)
+        self.element_names = self.super_cell.getElementNames()
         self.species = self.reader.getSpecies()
         covalent_radii = self.notebook.analysisTab.element_radii
         self.radii = [self.settings['Atom scaling']*covalent_radii[el] for el in self.element_names ]
@@ -414,10 +468,8 @@ class ViewerTab(QWidget):
         # reorder the displacement info in the normal modes into U,V and W lists
         # Using deque here rather than a simple list as the memory allocation doesn't have to be contiguous
         self.UVW.clear()
-        # self.UVW = []
         for mode,displacements in enumerate(self.normal_modes):
             uvw = deque()
-            #uvw = []
             for i in range(0,len(displacements),3):
                 uvw.append( displacements[i:i+3] )
             self.UVW.append(uvw)
@@ -429,7 +481,7 @@ class ViewerTab(QWidget):
         self.opengl_widget.deleteArrows()
         for uvw in self.UVW[self.selected_mode]:
             self.opengl_widget.addArrows( self.settings['Arrow colour'],self.settings['Arrow radius'], uvw, arrow_scaling )
-        self.opengl_widget.setRotationCentre(self.unit_cell.calculateCentreOfMass() )
+        self.opengl_widget.setRotationCentre( centreOfMassXYZ )
         self.opengl_widget.setImageSize()
         self.dirty = False
         QApplication.restoreOverrideCursor()
@@ -456,8 +508,6 @@ class ViewerTab(QWidget):
         maxR = np.amax(np.abs(UVW))
         self.scale_vibrations = self.settings['Maximum displacement'] / maxR
         self.newXYZ       = np.zeros( (self.settings['Number of phase steps'], self.natoms, 3) )
-        sign = +1.0
-        small = 1.0E-8
         n2 = int(self.settings['Number of phase steps']/2)
         delta = 1.0 / float(n2)
         phases = np.arange(-1.0, 1.0+delta-1.0E-10, delta)
@@ -476,7 +526,7 @@ class ViewerTab(QWidget):
                 self.opengl_widget.addSphere(col, rad, xyz, phase=phase_index )
             for p in self.cell_corners:
                 self.opengl_widget.addSphere(self.settings['Cell colour'], self.settings['Cell radius'], p, phase=phase_index )
-            for bond in self.unit_cell.bonds:
+            for bond in self.bonds:
                 i,j = bond
                 self.opengl_widget.addCylinder(self.settings['Bond colour'], self.settings['Bond radius'], self.newXYZ[phase_index,i], self.newXYZ[phase_index,j], phase=phase_index)
             for p1,p2 in self.cell_edges:
@@ -484,6 +534,22 @@ class ViewerTab(QWidget):
         debugger.print('calculatePhasePositions - exiting')
         return
 
+    def save_cif(self,filename):
+        #
+        # Write a single cif file containing all the phase information for discplacement along a mode
+        # First transform to abc coordinates from xyz
+        #
+        import copy
+        unitcell = copy.deepcopy(self.unit_cell)
+        n2 = int(self.settings['Number of phase steps']/2)
+        delta = 1.0 / float(n2)
+        phases = np.arange(-1.0, 1.0+delta-1.0E-10, delta)
+        with open(filename,'w') as fd:
+            for phase_index,phase in enumerate(phases):
+                description = 'mode_'+str(self.selected_mode)+'_phase_'+str(phase)
+                unitcell.set_xyz_coordinates(self.newXYZ[phase_index])
+                unitcell.write_cif(description,file_=fd)
+
     def plot(self):
         debugger.print('plot')
         if self.reader is None:
