@@ -1,20 +1,16 @@
 #!/usr/bin/env python
 """Read the contents of a directory containing DFT output and create a csv style file of information"""
 from __future__ import print_function
-import string
-import re
 import numpy as np
 import os, sys
-from PDielec.Constants import amu, PI, avogadro_si, wavenumber, angstrom, isotope_masses, average_masses
-from PDielec.VaspOutputReader import VaspOutputReader
-from PDielec.CastepOutputReader import CastepOutputReader
-from PDielec.GulpOutputReader import GulpOutputReader
-from PDielec.CrystalOutputReader import CrystalOutputReader
-from PDielec.AbinitOutputReader import AbinitOutputReader
-from PDielec.QEOutputReader import QEOutputReader
-from PDielec.PhonopyOutputReader import PhonopyOutputReader
-from multiprocessing import Pool, cpu_count
+import psutil
+from PDielec.Constants import amu, wavenumber, angstrom, isotope_masses, average_masses
+from multiprocess import Pool
+import dill as pickle
 import PDielec.Calculator as Calculator
+import PDielec.Utilities as Utilities
+import PDielec.__init__
+version = PDielec.__init__.__version__
 
 def set_affinity_on_worker():
     """When a new worker process is created, the affinity is set to all CPUs"""
@@ -24,82 +20,7 @@ def set_affinity_on_worker():
 
 def read_a_file( calling_parameters):
     name, eckart, neutral, mass_definition, mass_dictionary, global_no_calculation, program, hessian_symmetrisation, qmprogram, debug = calling_parameters
-    fulldirname = name
-    head,tail = os.path.split(fulldirname)
-    root,ext = os.path.splitext(tail)
-    if program == "castep":
-        names = [ name ]
-        reader = CastepOutputReader( names )
-    elif program == "vasp":
-        name1 = os.path.join(head,'OUTCAR')
-        name2 = os.path.join(head,'KPOINTS')
-        names = [ name1, name2 ]
-        reader = VaspOutputReader( names )
-    elif program == "gulp":
-        names = [ name ]
-        reader = GulpOutputReader( names )
-    elif program == "crystal":
-        names = [ name ]
-        reader = CrystalOutputReader( names )
-    elif program == "abinit":
-        names = [ name ]
-        reader = AbinitOutputReader( names )
-    elif program == "qe":
-        tail1 = root+'.dynG'
-        tail2 = root+'.log'
-        tail3 = root+'.out'
-        name1 = os.path.join(head,tail2)
-        name2 = os.path.join(head,tail3)
-        name3 = os.path.join(head,tail)
-        # We want the dynG entry last rounding causes problems otherwise
-        name4 = os.path.join(head,tail1)
-        names = []
-        for n in [ name1, name2, name3, name4 ]:
-            if os.path.isfile(n):
-                if not n in names:
-                    names.append(n)
-        reader = QEOutputReader( names )
-    elif program == "phonopy":
-        # The order is important
-        pname1 = os.path.join(head,'qpoints.yaml')
-        pname2 = os.path.join(head,'phonopy.yaml')
-        # Only works for VASP at the moment
-        vname1 = os.path.join(head,'OUTCAR')
-        vname2 = os.path.join(head,'KPOINTS')
-        pnames = [ pname1, pname2 ]
-        vnames = [ vname1, vname2 ]
-        pnames.extend(vnames)
-        names = pnames
-        # Which QM program was used by PHONOPY?
-        if qmprogram == "castep":
-            print("Error in qmreader",qmprogram)
-            exit()
-            qmreader = CastepOutputReader(names)
-        elif qmprogram == "vasp":
-            qmreader = VaspOutputReader(vnames)
-        elif qmprogram == "gulp":
-            print("Error in qmreader",qmprogram)
-            exit()
-            qmreader = GulpOutputReader(names)
-        elif qmprogram == "crystal":
-            print("Error in qmreader",qmprogram)
-            exit()
-            qmreader = CrystalOutputReader(names)
-        elif qmprogram == "abinit":
-            print("Error in qmreader",qmprogram)
-            exit()
-            qmreader = AbinitOutputReader(names)
-        elif qmprogram == "qe":
-            print("Error in qmreader",qmprogram)
-            exit()
-            qmreader = QEOutputReader(names)
-        # The QM reader is used to get info about the QM calculation
-        reader = PhonopyOutputReader(pnames,qmreader)
-    else:
-        print('Program name not recognized',program,file=sys.stderr)
-        exit()
-
-    print('  Analysing ',names, file=sys.stderr)
+    reader = Utilities.get_reader(name,program,qmprogram)
     # The order that the settings are applied is important
     # Symmetry is applied before the file is read, it is an integral part of the hessian
     # Eckart and neutral are applied after the file has been read, this way the original frequencies are those before any calculations
@@ -231,7 +152,7 @@ def read_a_file( calling_parameters):
     c13 = str(carray[0,2])
     c23 = str(carray[1,2])
     # Assemble the output line for the unprojected frequencies and all the other data
-    header = fulldirname + ',Read from program'
+    header = name + ',Read from program'
     string = ''
     string = string + ',' + str(reader.electrons)
     string = string + ',' + str(reader.magnetization)
@@ -263,67 +184,80 @@ def read_a_file( calling_parameters):
             option_string = option_string+' neutral'
         option_string = option_string+' hessian_symmetrisation='+hessian_symmetrisation
         option_string = option_string+' mass_definition='+mass_definition
-        header = fulldirname+','+option_string
+        header = name+','+option_string
         string = header + common_output
         for f in modified_frequencies_cm1:
             string = string + ',' + str(f)
         results_string.append(string)
         option_string = 'Calculated Intensities (Debye2/Angs2/amu)'
-        header = fulldirname+','+option_string
+        header = name+','+option_string
         string = header + common_output
         for f in intensities:
             string = string + ',' + str(f)
         results_string.append(string)
         option_string = 'Calculated Integrated Molar Absorption (L/mole/cm/cm)'
-        header = fulldirname+','+option_string
+        header = name+','+option_string
         string = header + common_output
         for f in intensities:
             string = string + ',' + str(f*4225.6)
         results_string.append(string)
     # End if not no_calculation
-    return name,results_string
+    return reader,name,results_string
+
+def print_help():
+    print('preader -program program [-eckart] [-neutral] [-nocalculation] [-hessian symm] [-masses average] [-pickle name] [-version] filenames .....', file=sys.stderr)
+    print('  \"program\" must be one of \"abinit\", \"castep\", \"crystal\", \"gulp\"       ', file=sys.stderr)
+    print('           \"phonopy\", \"qe\", \"vasp\", \"auto\"                               ', file=sys.stderr)
+    print('           The default is auto, so the program tries to guess the package from   ', file=sys.stderr)
+    print('           the contents of the directory.  However this is not fool-proof!       ', file=sys.stderr)
+    print('           If phonopy is used it must be followed by the QM package              ', file=sys.stderr)
+    print('           in auto mode if the file was created by a phonopy VASP is assumed     ', file=sys.stderr)
+    print('  -masses [average|isotope|program]  chooses the atomic mass definition average  ', file=sys.stderr)
+    print('          The default is \"average\"                                             ', file=sys.stderr)
+    print('  -mass  element mass                                                            ', file=sys.stderr)
+    print('          Change the mass of the element specified                               ', file=sys.stderr)
+    print('  -eckart projects out the translational components. Default is no projection    ', file=sys.stderr)
+    print('  -neutral imposes neutrality on the Born charges of the molecule.               ', file=sys.stderr)
+    print('           Default is no neutrality is imposed                                   ', file=sys.stderr)
+    print('  -hessian [symm|crystal] defines the symmetrisation of the hessian              ', file=sys.stderr)
+    print('           \"crystal\" imposes Crystal14 symmetrisation                          ', file=sys.stderr)
+    print('           \"symm\" symmetrises by averaging the hessian with its transpose      ', file=sys.stderr)
+    print('           \"symm\" is the default                                               ', file=sys.stderr)
+    print('  -nocalculation requests no calculations are performed                          ', file=sys.stderr)
+    print('           A single line is output with results obtained by reading the output   ', file=sys.stderr)
+    print('           any of -mass -masses -eckart -neutral or -crystal are ignored         ', file=sys.stderr)
+    print('  -debug   to switch on more debug information                                   ', file=sys.stderr)
+    print('  -pickle  write each file reader to a pickled dump file for later processing    ', file=sys.stderr)
+    print('           the name of the file to hold all the pickled readers is given         ', file=sys.stderr)
+    print('           If the file exists it is not overwritten                              ', file=sys.stderr)
+    print('  -version print the version of PDielec library being used                       ', file=sys.stderr)
+    print('  Version ',version,file=sys.stderr)
+    exit()
+
 
 def main():
     # Start processing the directories
     if len(sys.argv) <= 1 :
-        print('preader -program program [-eckart] [-neutral] [-nocalculation] [-hessian symm] [-masses average] filenames .....', file=sys.stderr)
-        print('  \"program\" must be one of \"abinit\", \"castep\", \"crystal\", \"gulp\"       ', file=sys.stderr)
-        print('           \"phonopy\", \"qe\", \"vasp\"                                         ', file=sys.stderr)
-        print('           If phonopy is used it must be followed by the QM package              ', file=sys.stderr)
-        print('  -masses [average|isotope|program]  chooses the atomic mass definition average  ', file=sys.stderr)
-        print('          The default is \"average\"                                             ', file=sys.stderr)
-        print('  -mass  element mass                                                            ', file=sys.stderr)
-        print('          Change the mass of the element specified                               ', file=sys.stderr)
-        print('  -eckart projects out the translational components. Default is no projection    ', file=sys.stderr)
-        print('  -neutral imposes neutrality on the Born charges of the molecule.               ', file=sys.stderr)
-        print('           Default is no neutrality is imposed                                   ', file=sys.stderr)
-        print('  -hessian [symm|crystal] defines the symmetrisation of the hessian              ', file=sys.stderr)
-        print('           \"crystal\" imposes Crystal14 symmetrisation                          ', file=sys.stderr)
-        print('           \"symm\" symmetrises by averaging the hessian with its transpose      ', file=sys.stderr)
-        print('           \"symm\" is the default                                               ', file=sys.stderr)
-        print('  -nocalculation requests no calculations are performed                          ', file=sys.stderr)
-        print('           A single line is output with results obtained by reading the output   ', file=sys.stderr)
-        print('           any of -mass -masses -eckart -neutral or -crystal are ignored         ', file=sys.stderr)
-        print('  -debug   to switch on more debug information                                   ', file=sys.stderr)
-        exit()
-
+        print_help()
     observables=False
     files = []
     eckart = False
     neutral = False
-    hessian_symmetrisation = "symm"
+    hessian_symmetrisation = None
     mass_definition = "average"
     mass_dictionary = {}
     global_no_calculation = False
     tokens = sys.argv[1:]
     ntokens = len(tokens)-1
     itoken = -1
-    program = ''
-    qmprogram = ''
+    program = 'auto'
+    qmprogram = 'vasp'
     debug = False
+    picklefile = None
     while itoken < ntokens:
         itoken += 1
         token = tokens[itoken]
+        token = token.replace('--','-')
         if token == "-observables":
             observables = True
         elif token == "-debug":
@@ -356,11 +290,27 @@ def main():
             itoken += 1
             mass = float(tokens[itoken])
             mass_dictionary[element] = mass
+        elif token == "-help":
+            print_help()
+        elif token == "-version":
+            print('  Version ',version,file=sys.stderr)
+            exit()
         elif token == "-nocalculation":
             global_no_calculation = True
+        elif token == "-pickle":
+            itoken += 1
+            picklefile = tokens[itoken]
+            if os.path.isfile(picklefile):
+                print('Error: pickle file {} already exists'.format(picklefile),file=sys.stderr)
+                exit()
         elif token == "-program":
             itoken += 1
             program = tokens[itoken]
+            if hessian_symmetrisation == None:
+                if program == 'crystal':
+                    hessian_symmetrisation = 'crystal'
+                else:
+                    hessian_symmetrisation = 'symm'
             if program == 'phonopy':
                 itoken += 1
                 qmprogram = tokens[itoken]
@@ -371,7 +321,7 @@ def main():
         print('Please use -program to define the package used to generate the output files',file=sys.stderr)
         exit()
 
-    if not program in ['abinit','castep','crystal','gulp','qe','vasp','phonopy']:
+    if not program in ['auto','abinit','castep','crystal','gulp','qe','vasp','phonopy']:
         print('Program is not recognised: ',program,file=sys.stderr)
         exit()
 
@@ -412,20 +362,38 @@ def main():
     #
     # Create a pool of processors to handle reading the files
     #
-    p = Pool(initializer=set_affinity_on_worker)
+    number_of_processors = psutil.cpu_count(logical=False)
+    p = Pool(number_of_processors,initializer=set_affinity_on_worker)
     # Create a tuple list of calling parameters
     calling_parameters = []
     files.sort()
     for name in files:
-        calling_parameters.append( (name, eckart, neutral, mass_definition, mass_dictionary, global_no_calculation, program, hessian_symmetrisation, qmprogram, debug) )
+        prog = program
+        if program == "auto":
+            prog = find_program_from_name(name)
+            if hessian_symmetrisation == None:
+                if prog == 'crystal':
+                    hessian_symmetrisation = 'crystal'
+                else:
+                    hessian_symmetrisation = 'symm'
+            print('  Analysing {} generated by {}'.format(name,prog),file=sys.stderr)
+        calling_parameters.append( (name, eckart, neutral, mass_definition, mass_dictionary, global_no_calculation, prog, hessian_symmetrisation, qmprogram, debug) )
     # Calculate the results in parallel
     results_map_object = p.map_async(read_a_file,calling_parameters)
     results_map_object.wait()
     results = results_map_object.get()
     # Convert the results into a dictionary
     results_dictionary = {}
-    for name,strings in results:
+    # If pickling then open the pickle file
+    if picklefile:
+        picklefd = open(picklefile,'wb')
+    for reader,name,strings in results:
         results_dictionary[name] = strings
+        if picklefile:
+            pickle.dump(reader,picklefd)
+    # If pickling then close the pickle file
+    if picklefile:
+        picklefd.close()
     # Print out the results
     print('directory,information,electrons,magnetization,kpnts,kpnt_1,kpnt_2,kpnt_3,energy_cutoff_eV,final_free_energy_eV,final_energy_without_entropy_eV,pressure_GPa,a_A,b_A,c_A,alpha,beta,gamma,volume,eps0_xx,eps0_yy,eps0_zz,eps0_xy,eps0_xz,eps0_yz,epsinf_xx,epsinf_yy,epsinf_zz,epsinf_xy,epsinf_xz,epsinf_yz, c11_gpa, c22_gpa, c33_gpa, c44_gpa, c55_gpa, c66_gpa, c12_gpa,  c13_gpa, c23_gpa,f1,f2,f3,f4,f5,f6....')
     for name in files:
@@ -496,4 +464,4 @@ def main():
 # end of def main
 
 if __name__ == "__main__":
-    main(sys)
+    main()
